=======
History
=======

0.2.0 (2021-08-04)
------------------

**New Features**

* **PortfolioOptimizer [object]:** Optimize your portfolio based on Sharpe Ratio.
    * **fit [method]:** Fits daily stock data into the optimizer. Generates annual measures.
    * **plot_efficient_frontier [method]:** Generates a plot for efficient frontier, optimal portfolio, and individual stocks.


0.1.0 (2021-07-30)
------------------

* First release on PyPI.
